==> topia-service-migration-2.3.3-sources.jar: org/nuiton/topia/migration/callback/MigrationCallbackHandler.java <==
/*
 * #%L
 * ToPIA :: Service Migration
 * 
 * $Id: MigrationCallbackHandler.java 1894 2010-04-15 15:44:51Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/topia/tags/topia-2.3.3/topia-service-migration/src/main/java/org/nuiton/topia/migration/callback/MigrationCallbackHandler.java $
 * %%
 * Copyright (C) 2004 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.topia.migration.callback;

import org.nuiton.topia.migration.DatabaseManager;

/**
 * MigrationCallBackHandler
 *
 * @author chatellier
 * @version $Revision: 1894 $
 *
 * Last update : $Date: 2010-04-15 17:44:51 +0200 (jeu., 15 avril 2010) $
 * By : $Author: tchemit $
 */
public interface MigrationCallbackHandler {

    /**
     * CallbackHandler return type.
     */
    enum MigrationChoice {
        // no migration

        NO_MIGRATION,
        // migration
        MIGRATION,
        // migration done by application, only version managed
        CUSTOM_MIGRATION
    }

    /**
     * Ask for migration
     * 
     * @param dbManager objet permettant d'ouvrir des connexions sur la base
     * @param databaseVersion database version
     * @param applicationVersion application version
     * @return migration aggrement
     */
    MigrationChoice doMigration(DatabaseManager dbManager,
                                String databaseVersion,
                                String applicationVersion);
}

==> topia-service-migration-2.3.4-sources.jar: org/nuiton/topia/migration/callback/MigrationCallbackHandler.java <==
/*
 * #%L
 * ToPIA :: Service Migration
 * 
 * $Id: MigrationCallbackHandler.java 2010 2010-06-13 18:18:35Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/topia/tags/topia-2.3.4/topia-service-migration/src/main/java/org/nuiton/topia/migration/callback/MigrationCallbackHandler.java $
 * %%
 * Copyright (C) 2004 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.topia.migration.callback;

import org.nuiton.topia.migration.DatabaseManager;
import org.nuiton.topia.migration.TopiaMigrationEngine;

/**
 * MigrationCallBackHandler
 *
 * @author chatellier
 * @deprecated since 2.3.4, please use now the simplify service {@link TopiaMigrationEngine}
 */
@Deprecated
public interface MigrationCallbackHandler {

    /**
     * CallbackHandler return type.
     */
    enum MigrationChoice {
        // no migration

        NO_MIGRATION,
        // migration
        MIGRATION,
        // migration done by application, only version managed
        CUSTOM_MIGRATION
    }

    /**
     * Ask for migration
     * 
     * @param dbManager objet permettant d'ouvrir des connexions sur la base
     * @param databaseVersion database version
     * @param applicationVersion application version
     * @return migration aggrement
     */
    MigrationChoice doMigration(DatabaseManager dbManager,
                                String databaseVersion,
                                String applicationVersion);
}
